.. _user-interface:
.. index:: userinterface

User Interface
==============

:program:`PyTessel` uses two functions for the construction of isosurfaces:

* :code:`marching_cubes`
* :code:`write_ply`

Isosurface generation
---------------------

.. automethod:: pytessel.PyTessel.marching_cubes

Storing the isosurface
----------------------

.. automethod:: pytessel.PyTessel.write_ply
